summaryrefslogtreecommitdiffstats
path: root/kig/objects/object_factory.cc
diff options
context:
space:
mode:
Diffstat (limited to 'kig/objects/object_factory.cc')
-rw-r--r--kig/objects/object_factory.cc6
1 files changed, 3 insertions, 3 deletions
diff --git a/kig/objects/object_factory.cc b/kig/objects/object_factory.cc
index f2957a7e..942139f4 100644
--- a/kig/objects/object_factory.cc
+++ b/kig/objects/object_factory.cc
@@ -299,12 +299,12 @@ void ObjectFactory::redefinePoint(
std::mem_fun( calcmeth ) );
ObjectCalcer* v = 0;
- // we don't want one of our children as a parent...
- std::set<ObjectCalcer*> children = getAllChildren( point );
+ // we don't want one of our tqchildren as a parent...
+ std::set<ObjectCalcer*> tqchildren = getAllChildren( point );
for ( std::vector<ObjectCalcer*>::iterator i = os.begin();
i != os.end(); ++i )
if ( (*i)->imp()->inherits( CurveImp::stype() ) &&
- children.find( *i ) == children.end() )
+ tqchildren.find( *i ) == tqchildren.end() )
{
v = *i;
break;